==> monache-lib-0.2.0-20140518.zip: monache-lib-0.2.0/src/main/java/org/monache/lib/api/impl/WalletLockImpl.java <==
/*
 * WalletLockImpl.java
 *
 * Copyright 2014 the Monache.org.
 * http://www.monache.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.monache.lib.api.impl;

import org.monache.lib.api.AbstractCoinAPI;
import org.monache.lib.api.CoinAPIException;
import org.monache.lib.api.WalletLock;
import org.monache.lib.api.result.WalletLockResult;
import org.monache.lib.jsonrpc.JsonRPCClient;
import org.monache.lib.jsonrpc.JsonRPCv1RequestObject;
import org.monache.lib.jsonrpc.JsonRPCv1ResponseObject;

/**
 * 
 * 
 * @author monache.org
 * @since 1.0
 */
public class WalletLockImpl extends AbstractCoinAPI implements WalletLock {

	protected static final String METHOD = "walletlock";
	
	/**
	 * 
	 * @since 1.0
	 */
	public WalletLockImpl() {
	}

	/*
	 * (非 Javadoc)
	 * @see org.monache.lib.api.WalletLock#call(org.monache.lib.jsonrpc.JsonRPCClient)
	 * @since 1.0
	 */
	public WalletLockResult call(JsonRPCClient jsonRPCClient) throws CoinAPIException {
		try {
			if (jsonRPCClient == null) {
				throw new NullPointerException("jsonRPCClient is null.");
			}

			// request
			JsonRPCv1RequestObject requestObject = new JsonRPCv1RequestObject();
			requestObject.setMethod(METHOD);

			// JSON-RPC call
			JsonRPCv1ResponseObject responseObject = jsonRPCClient.call(requestObject, JsonRPCv1ResponseObject.class);
			
			// Create a result object
			WalletLockResult result = new WalletLockResult();
			// JSON string
			result.setJsonString(responseObject.getJsonString());
			return result;

		} catch (Exception e) {
			// JsonRPCException
			throw new CoinAPIException("Error: " + e.getMessage(), e);
		}
	}

}

==> monache-lib-0.3.0-20140527.zip: monache-lib-0.3.0/src/main/java/org/monache/lib/api/impl/WalletLockImpl.java <==
/*
 * WalletLockImpl.java
 *
 * Copyright 2014 the Monache.org.
 * http://www.monache.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.monache.lib.api.impl;

import org.monache.lib.api.AbstractCoinAPI;
import org.monache.lib.api.CoinAPIException;
import org.monache.lib.api.WalletLock;
import org.monache.lib.api.response.WalletLockResponseObject;
import org.monache.lib.api.result.WalletLockResult;
import org.monache.lib.jsonrpc.JsonRPCClient;
import org.monache.lib.jsonrpc.JsonRPCv1RequestObject;

/**
 * 
 * 
 * @author monache.org
 * @since 1.0
 */
public class WalletLockImpl extends AbstractCoinAPI implements WalletLock {

	protected static final String METHOD = "walletlock";
	
	/**
	 * 
	 * @since 1.0
	 */
	public WalletLockImpl() {
	}

	/*
	 * (非 Javadoc)
	 * @see org.monache.lib.api.WalletLock#call(org.monache.lib.jsonrpc.JsonRPCClient)
	 * @since 1.0
	 */
	public WalletLockResult call(JsonRPCClient jsonRPCClient) throws CoinAPIException {
		try {
			if (jsonRPCClient == null) {
				throw new NullPointerException("jsonRPCClient is null.");
			}

			// request
			JsonRPCv1RequestObject requestObject = new JsonRPCv1RequestObject();
			requestObject.setMethod(METHOD);

			// JSON-RPC call
			return jsonRPCClient.call(requestObject, WalletLockResponseObject.class).getResultObject();

		} catch (Exception e) {
			// JsonRPCException
			throw new CoinAPIException("Error: " + e.getMessage(), e);
		}
	}

}
